@@ -1,13 +1,21 @@
 import httpx
 
-from ._decorators import raise_for_status, http_retry, raise_for_status_async
+from ._decorators import (
+    raise_for_status,
+    raise_for_status_async,
+)
+
+from ._retry_strategy import RetryStrategy
 
 
 class BlobClient:
     """Upload blobs to blob store using pre-authorized URLs"""
 
+    def __init__(self, retry_strategy=RetryStrategy()):
+        self._retry_strategy = retry_strategy
+        return
+
     @raise_for_status
-    @http_retry
     def upload_blob(self, blob: bytes, url: str):
         """Upload a blob.
 
@@ -21,12 +29,14 @@ class BlobClient:
             "x-ms-blob-type": "BlockBlob",
         }
 
-        response = httpx.put(url, content=blob, headers=headers)
+        def _put():
+            return httpx.put(url, content=blob, headers=headers)
 
-        return response
+        retryer = self._retry_strategy.make_retryer()
+
+        return retryer(_put)
 
     @raise_for_status_async
-    @http_retry
     async def upload_blob_async(self, blob: bytes, url: str):
         """Upload a blob async.
 
@@ -40,7 +50,10 @@ class BlobClient:
             "x-ms-blob-type": "BlockBlob",
         }
 
-        async with httpx.AsyncClient() as client:
-            response = await client.put(url=url, content=blob, headers=headers)
+        async def _put():
+            async with httpx.AsyncClient() as client:
+                return await client.put(url=url, content=blob, headers=headers)
 
-        return response
+        retryer = self._retry_strategy.make_retryer()
+
+        return await retryer(_put)
